@@ -31,7 +31,7 @@ import xdg.BaseDirectory
 
 def _(message): return message
 
-VERSION = '0.8.0.2'
+VERSION = '0.8.5'
 DESCRIPTION = _('Connect to a world of online tutorials quickly and easily.')
 WEBSITE = 'http://wiki.ubuntu.com/Lernid'
 CONTRIBUTORS = [
@@ -46,6 +46,7 @@ CONTRIBUTORS = [
     "Peeyoosh Sangolekar <piyush_sangolekar@hotmail.com>",
     "Sanne Wouda <sanne@gruttepier.net>",
     "Sense Hofstede <sense@qense.nl>",
+    "John S Gruber <johnsgruber@gmail.com>",
 ]
 ARTISTS = [
     'K.Vishnoo Charan Reddy <foo.mac.v@gmail.com>'
