@@ -22,8 +22,13 @@ import gobject
 import webkit
 import logging
 import re
+import webbrowser
 
 from lernid.widgets.Widget import Widget
+from lernid.LernidOptions import Options
+from urlparse import urlparse
+from lernid.lernidconfig import get_data_path, VERSION
+from lernid.LernidPreferences import Preferences
 
 class Browser(Widget):
 
@@ -47,6 +52,15 @@ class Browser(Widget):
         builder = self.builder_with_file('BrowserWidget.ui')
         self.add(builder.get_object('browser_vbox'))
         self._browser = webkit.WebView()
+        
+        browser_settings=webkit.WebSettings()
+        useragent=browser_settings.get_property('user-agent')
+        parts=useragent.split(' ')
+        parts[-1]='lernid/'+VERSION
+        browser_settings.set_property('user-agent', ' '.join(parts))
+        browser_settings.set_property('enable-plugins', False)
+        self._browser.set_settings(browser_settings)
+        
         scroll = builder.get_object('browser_scroll')
         scroll.add(self._browser)
 
@@ -81,6 +95,9 @@ class Browser(Widget):
 
         self._toolbar.set_sensitive(False)
 
+        self._browser_settings = self._browser.get_settings()
+        self._browser_settings.set_property('user-stylesheet-uri', 'file://'+get_data_path()+'/stylesheet')
+
     def do_event_connect(self, eventman, event):
         classroom = eventman.get_widget_by_name('classroom')
         self.event_connect_signal(classroom, 'message-received', self._classroom_msg_received)
@@ -88,7 +105,10 @@ class Browser(Widget):
         self._browser.show()
         # FIXME: why does the button not follow sensitive state of the toolbar?
         self._pause_button.set_sensitive(True)
-        self.set_location(event.homepage)
+        #  Ideally the homepage should be opened inside Lernid itself
+        self.set_location(event.homepage, False)
+        schedule = eventman.get_widget_by_name('schedule')
+        self._on_faculty = schedule.on_faculty # retrieve method
 
     def do_event_disconnect(self, eventman, event):
         self._url_combo.handler_block_by_func(self._change_page)
@@ -107,10 +127,17 @@ class Browser(Widget):
     def get_location(self):
         return self._browser.get_property('uri')
 
-    def set_location(self, url):
+    def set_location(self, url, in_default_browser = True):
+        if urlparse(url).scheme == '':
+                url = 'http://' + url
         logging.debug('opening url: '+url)
-        self._browser.open(url)
-        self.emit('page-changed', url)
+        # check if prefernce is set and the link was inside chat
+        if Preferences.get('links_in_default_browser') and in_default_browser:
+            webbrowser.open_new_tab(url)
+            logging.debug('opening url in tab in default browser: '+url)
+        else:
+            self._browser.open(url)
+            self.emit('page-changed', url)
 
     def _back(self, button):
         self._browser.go_back()
@@ -138,6 +165,8 @@ class Browser(Widget):
     def _update_url_combo(self, browser, *args):
         """Update the browser url combo box with the new title."""
         url = browser.get_property('uri')
+        if url == None: 
+            url = ''
         logging.debug('update url combo: {0}'.format(url))
         if url == 'about:blank':
             return
@@ -177,6 +206,8 @@ class Browser(Widget):
             self.set_location(url)
 
     def _classroom_msg_received(self, classroom, chan, sender, text):
+        if not Options.get('unsafe-override') and not self._on_faculty(sender):
+            return
         load, ignore = self._parse_urls(text)
         if load and not self._paused:
             self.set_location(load)
@@ -198,6 +229,7 @@ class Browser(Widget):
             if any([url.endswith(c) for c in '.;:]']):
                 url = url[:-1]
             return url
+        if re.search("slidefile", message, re.IGNORECASE): return (load, ignore)
         urls = re.findall("(\[?https?://[^\s\)]*)[\s\)\.\]]?", message, re.IGNORECASE)
         for url in urls:
             if (url.startswith('[') and url.endswith(']')) or load:
