@@ -24,7 +24,7 @@ import time
 import re
 
 from lernid.widgets.Widget import Widget
-from lernid.CouchDBPreferences import Preferences
+from lernid.LernidPreferences import Preferences
 
 from lernid import IrcBackend
 
@@ -43,6 +43,10 @@ class IrcWidget(Widget):
     def do_event_connect(self, event_man, event):
         self._browser = event_man.get_widget_by_name('browser')
         self.get_toplevel().connect('focus-out-event', self._focus_out)
+        schedule = event_man.get_widget_by_name('schedule')
+        self._on_faculty = schedule.on_faculty # retrieve method
+        self._classbotnames = event_man.classbotnames
+
 
     def _init_hyperlinks(self):
         hyperlink_tag = self._buffer.create_tag('hyperlink', foreground='#0000ff',
@@ -73,13 +77,21 @@ class IrcWidget(Widget):
         else:
             if sender:
                 self._buffer.insert_with_tags_by_name(iend, '<%s> ' % sender, 'gray')
-            start_pos = iend.get_offset()
-            if self._nick in text and sender != self._nick:
-                self._buffer.insert_with_tags_by_name(iend, text, 'highlight')
+                start_pos = iend.get_offset()
+                my_nick = self._chan._conn._acquired_nick
+                if my_nick in text and sender != my_nick:
+                    self._buffer.insert_with_tags_by_name(iend, text, 'highlight')
+                elif self._on_faculty(sender):
+                    self._buffer.insert_with_tags_by_name(iend, text, 'highlight')
+                elif sender.lower() in self._classbotnames:
+                    self._buffer.insert_with_tags_by_name(iend, text, 'italicize')
+                else: self._buffer.insert(iend, text)
             else:
                 self._buffer.insert(iend, text)
 
-        for url in re.finditer(r"https?://\S+", unicode(text, 'utf-8')):
+        if type(text)!=unicode:
+            text=unicode(text, 'utf-8')
+        for url in re.finditer(r"https?://\S+", text):
             self._buffer.apply_tag_by_name('hyperlink',
                 self._buffer.get_iter_at_offset(start_pos + url.start()),
                 self._buffer.get_iter_at_offset(start_pos + url.end()))
